#!/bin/bash

AUTH_SUCCESS="1"
AUTH_FAILURE="0"

# Function to write the value to the control file and exit
respond_with() {
  value=$1
  control_path=$2
  echo "$value" > "$control_path"
  exit 0
}

# Read the username and password from the environment variables passed by OpenVPN
username=$username
password=$password

# Read the auth_control_file from the environment variable passed by OpenVPN
auth_control_file=$auth_control_file

# Path to the JSON file
USER_JSON_FILE="/etc/openvpn/script/users/users"

# Extract and parse each user's information
user_info=$(jq -r --argjson username "$username" '.[] | fromjson | select(.username == $username)' "$USER_JSON_FILE")

# Check if the user exists in the JSON file
if [ -n "$user_info" ]; then
  # Extract the hashed password from the parsed user info
  hashed_password=$(echo "$user_info" | jq -r '.password')

  # Verify the password using bcrypt
  if bcrypt-tool match "$password" "$hashed_password" | grep -q "yes"; then
    # Respond with success if the password matches
    respond_with "$AUTH_SUCCESS" "$auth_control_file"
  fi
fi

# If the authentication failed, respond with failure
respond_with "$AUTH_FAILURE" "$auth_control_file"
